==> 3.4.0.tar.gz: ios/Classes/Mapping/Error/ErrorMapper.swift <==
//
// Copyright © 2022 Nevis Security AG. All rights reserved.
//

import Darwin
import Flutter
import NevisMobileAuthentication

extension FlutterError {
	convenience init(message: String) {
		self.init(code: String(), message: message, details: nil)
	}
}

extension Error {
	/// Converts `Error` type to Flutter error by specifing the properties that is processable on Dart side.
	///
	/// If the `code` is empty, it will be treated as a `PlatformChannelException` with an `unknownError` `PlatformChannelError`,
	/// and only the message will be processed.
	/// If the `details` is not empty, it must be a serialized `ChannelError`.
	///
	/// - note: The method is used only in the `NevisMobileAuthenticationSdkFlutterSwift` class.
	/// - returns: The created `FlutterError` instance.
	func asFlutterError() -> FlutterError {
		if let error = self as? DeleteAuthenticatorError {
			return error.asFlutterError()
		}

		if let clientError = self as? MobileAuthenticationClientError {
			return clientError.asFlutterError()
		}

		if let error = self as? DecodingError {
			return error.asFlutterError()
		}

		if let error = self as? EncodingError {
			return error.asFlutterError()
		}

		// Each non-client error will be mapped as a PlatformChannelException
		// with an `unknownError` PlatformChannelError and only the message will be shown
		return FlutterError(message: localizedDescription)
	}
}

extension MobileAuthenticationClientError {
	func asChannelError() -> ChannelError {
		let mirror = mirror
		let type = mirror.label // enum name
		let params = mirror.params // associated values (name: value)

		let cause = (params[ErrorKey.cause.rawValue] as? Error)?.localizedDescription
		let fidoError = params[ErrorKey.errorCode.rawValue] as? FidoErrorCode
		var typedSessionProvider: TypedSessionProvider?
		if let sessionProvider = params[ErrorKey.sessionProvider.rawValue] as? SessionProvider {
			typedSessionProvider = TypedSessionProvider(wrapped: sessionProvider)
		}

		return ChannelError(type: type,
		                    description: localizedDescription,
		                    innerError: fidoError,
		                    sessionProvider: typedSessionProvider ?? nil,
		                    cause: cause)
	}

	func asFlutterError() -> FlutterError {
		FlutterError(message: localizedDescription)
	}
}

extension DeleteAuthenticatorError {
	func asFlutterError() -> FlutterError {
		let mirror = mirror
		let type = mirror.label // enum name
		let params = mirror.params // associated values (name: value)

		var errorData = [ErrorKey.description.rawValue: localizedDescription]
		if let cause = (params[ErrorKey.cause.rawValue] as? Error)?.localizedDescription {
			errorData[ErrorKey.cause.rawValue] = cause
		}

		let details: [String : Any] = [ErrorKey.type.rawValue: type,
									   ErrorKey.data.rawValue: errorData]
		return FlutterError(code: PlatformChannelError.deleteAuthenticator.rawValue,
		                    message: localizedDescription,
		                    details: details)
	}
}

extension DecodingError {
	func asFlutterError() -> FlutterError {
		var description = String()
		switch self {
		case let .dataCorrupted(context):
			description = context.debugDescription
		case let .keyNotFound(key, context):
			description = "Key not found. Expected -> \(key.stringValue) <- at: \(context.prettyPath())"
		case let .typeMismatch(_, context):
			description = "Type mismatch. \(context.debugDescription), at: \(context.prettyPath())"
		case let .valueNotFound(_, context):
			description = "Value not found. -> \(context.prettyPath()) <- \(context.debugDescription)"
		@unknown default:
			description = String()
		}

		let data = [ErrorKey.description.rawValue: description]
		let details: [String: Any] = [ErrorKey.type.rawValue: PlatformChannelError.mapping.rawValue,
		                              ErrorKey.data.rawValue: data]
		return FlutterError(code: String(),
		                    message: localizedDescription,
		                    details: details)
	}
}

extension DecodingError.Context {
	func prettyPath(separatedBy separator: String = ".") -> String {
		codingPath.map(\.stringValue).joined(separator: separator)
	}
}

extension EncodingError {
	func asFlutterError() -> FlutterError {
		var description = String()
        if case .invalidValue(_, let context) = self {
            description = "Invalid value. -> \(context.prettyPath()) <- \(context.debugDescription)"
        }

		let data = [ErrorKey.description.rawValue: description]
		let details: [String: Any] = [ErrorKey.type.rawValue: PlatformChannelError.mapping.rawValue,
		                              ErrorKey.data.rawValue: data]
		return FlutterError(code: String(),
		                    message: localizedDescription,
		                    details: details)
	}
}

extension EncodingError.Context {
	func prettyPath(separatedBy separator: String = ".") -> String {
		codingPath.map(\.stringValue).joined(separator: separator)
	}
}

==> 3.5.1.tar.gz: ios/Classes/Mapping/Error/ErrorMapper.swift <==
//
// Copyright © 2022 Nevis Security AG. All rights reserved.
//

import Darwin
import Flutter
import NevisMobileAuthentication

extension FlutterError {
	convenience init(message: String) {
		self.init(code: String(), message: message, details: nil)
	}
}

extension Error {
	/// Converts `Error` type to Flutter error by specifing the properties that is processable on Dart side.
	///
	/// If the `code` is empty, it will be treated as a `PlatformChannelException` with an `unknownError` `PlatformChannelError`,
	/// and only the message will be processed.
	/// If the `details` is not empty, it must be a serialized `ChannelError`.
	///
	/// - note: The method is used only in the `NevisMobileAuthenticationSdkFlutterSwift` class.
	/// - returns: The created `FlutterError` instance.
	func asFlutterError() -> FlutterError {
		if let error = self as? DeleteAuthenticatorError {
			return error.asFlutterError()
		}

		if let clientError = self as? MobileAuthenticationClientError {
			return clientError.asFlutterError()
		}

		if let error = self as? DecodingError {
			return error.asFlutterError()
		}

		if let error = self as? EncodingError {
			return error.asFlutterError()
		}

		// Each non-client error will be mapped as a PlatformChannelException
		// with an `unknownError` PlatformChannelError and only the message will be shown
		return FlutterError(message: localizedDescription)
	}
}

extension MobileAuthenticationClientError {
	func asChannelError() -> ChannelError {
		let mirror = mirror
		let type = mirror.label // enum name
		let params = mirror.params // associated values (name: value)

		let cause = (params[ErrorKey.cause.rawValue] as? Error)?.localizedDescription
		let fidoError = params[ErrorKey.errorCode.rawValue] as? FidoErrorCode
		var typedSessionProvider: TypedSessionProvider?
		if let sessionProvider = params[ErrorKey.sessionProvider.rawValue] as? SessionProvider {
			typedSessionProvider = TypedSessionProvider(wrapped: sessionProvider)
		}

		return ChannelError(type: type,
		                    description: localizedDescription,
		                    innerError: fidoError,
		                    sessionProvider: typedSessionProvider ?? nil,
		                    cause: cause)
	}

	func asFlutterError() -> FlutterError {
		FlutterError(message: localizedDescription)
	}
}

extension DeleteAuthenticatorError {
	func asFlutterError() -> FlutterError {
		let mirror = mirror
		let type = mirror.label // enum name
		let params = mirror.params // associated values (name: value)

		var errorData = [ErrorKey.description.rawValue: localizedDescription]
		if let cause = (params[ErrorKey.cause.rawValue] as? Error)?.localizedDescription {
			errorData[ErrorKey.cause.rawValue] = cause
		}

		let details: [String: Any] = [ErrorKey.type.rawValue: type,
		                              ErrorKey.data.rawValue: errorData]
		return FlutterError(code: PlatformChannelError.deleteAuthenticator.rawValue,
		                    message: localizedDescription,
		                    details: details)
	}
}

extension DecodingError {
	func asFlutterError() -> FlutterError {
		var description = String()
		switch self {
		case let .dataCorrupted(context):
			description = context.debugDescription
		case let .keyNotFound(key, context):
			description = "Key not found. Expected -> \(key.stringValue) <- at: \(context.prettyPath())"
		case let .typeMismatch(_, context):
			description = "Type mismatch. \(context.debugDescription), at: \(context.prettyPath())"
		case let .valueNotFound(_, context):
			description = "Value not found. -> \(context.prettyPath()) <- \(context.debugDescription)"
		@unknown default:
			description = String()
		}

		let data = [ErrorKey.description.rawValue: description]
		let details: [String: Any] = [ErrorKey.type.rawValue: PlatformChannelError.mapping.rawValue,
		                              ErrorKey.data.rawValue: data]
		return FlutterError(code: String(),
		                    message: localizedDescription,
		                    details: details)
	}
}

extension DecodingError.Context {
	func prettyPath(separatedBy separator: String = ".") -> String {
		codingPath.map(\.stringValue).joined(separator: separator)
	}
}

extension EncodingError {
	func asFlutterError() -> FlutterError {
		var description = String()
		if case let .invalidValue(_, context) = self {
			description = "Invalid value. -> \(context.prettyPath()) <- \(context.debugDescription)"
		}

		let data = [ErrorKey.description.rawValue: description]
		let details: [String: Any] = [ErrorKey.type.rawValue: PlatformChannelError.mapping.rawValue,
		                              ErrorKey.data.rawValue: data]
		return FlutterError(code: String(),
		                    message: localizedDescription,
		                    details: details)
	}
}

extension EncodingError.Context {
	func prettyPath(separatedBy separator: String = ".") -> String {
		codingPath.map(\.stringValue).joined(separator: separator)
	}
}
